summaryrefslogtreecommitdiffstats
path: root/chrome/browser/plugin_updater.cc
diff options
context:
space:
mode:
authormnissler@chromium.org <mnissler@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-16 11:23:17 +0000
committermnissler@chromium.org <mnissler@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-16 11:23:17 +0000
commitfda165787a252f0fd424f7137619f0bf0c1482dd (patch)
tree5daa7fb4fbc0dfc64b9d19644935df6403d4194a /chrome/browser/plugin_updater.cc
parent28ecba3ff7ea1aac62c1a74e2d75bd1ccb42caa6 (diff)
downloadchromium_src-fda165787a252f0fd424f7137619f0bf0c1482dd.zip
chromium_src-fda165787a252f0fd424f7137619f0bf0c1482dd.tar.gz
chromium_src-fda165787a252f0fd424f7137619f0bf0c1482dd.tar.bz2
Support wildcards for policy-controlled plugin blacklists.
BUG=53158 TEST=Configure wildcard blacklist pattern and check whether plugins get disabled in about:plugins. Review URL: http://codereview.chromium.org/3435001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@59635 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/plugin_updater.cc')
-rw-r--r--chrome/browser/plugin_updater.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/plugin_updater.cc b/chrome/browser/plugin_updater.cc
index 280db00..3430697 100644
--- a/chrome/browser/plugin_updater.cc
+++ b/chrome/browser/plugin_updater.cc
@@ -126,20 +126,20 @@ void PluginUpdater::Observe(NotificationType type,
}
void PluginUpdater::DisablePluginsFromPolicy(const ListValue* plugin_names) {
// Generate the set of unique disabled plugins from the disabled
// plugins list.
- std::set<string16> policy_disabled_plugins;
+ std::set<string16> policy_disabled_plugin_patterns;
if (plugin_names) {
ListValue::const_iterator end(plugin_names->end());
for (ListValue::const_iterator current(plugin_names->begin());
current != end; ++current) {
string16 plugin_name;
if ((*current)->GetAsString(&plugin_name)) {
- policy_disabled_plugins.insert(plugin_name);
+ policy_disabled_plugin_patterns.insert(plugin_name);
}
}
}
- PluginGroup::SetPolicyDisabledPluginSet(policy_disabled_plugins);
+ PluginGroup::SetPolicyDisabledPluginPatterns(policy_disabled_plugin_patterns);
// Disable all of the plugins and plugin groups that are disabled by policy.
// There's currenly a bug that makes it impossible to correctly re-enable
@@ -259,7 +259,7 @@ void PluginUpdater::DisablePluginGroupsFromPrefs(Profile* profile) {
}
}
// Build the set of policy-disabled plugins once and cache it.
// Don't do this in the constructor, there's no profile available there.
const ListValue* plugin_blacklist =
profile->GetPrefs()->GetList(prefs::kPluginsPluginsBlacklist);
@@ -126,20 +126,20 @@ void PluginUpdater::Observe(NotificationType type,
}
void PluginUpdater::DisablePluginsFromPolicy(const ListValue* plugin_names) {
- // Generate the set of unique disabled plugins from the disabled
+ // Generate the set of unique disabled plugin patterns from the disabled
// plugins list.
@@ -259,7 +259,7 @@ void PluginUpdater::DisablePluginGroupsFromPrefs(Profile* profile) {
}
}
- // Build the set of policy-disabled plugins once and cache it.
+ // Build the set of policy-disabled plugin patterns once and cache it.
// Don't do this in the constructor, there's no profile available there.
const ListValue* plugin_blacklist =